@@ -1,17 +1,14 @@
 package Map::Tube::Kharkiv;
 
-# Pragmas.
 use strict;
 use warnings;
 use 5.006;
 
-# Modules.
 use File::Share ':all';
 use Moo;
 use namespace::clean;
 
-# Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Get XML.
 has xml => (
@@ -36,6 +33,7 @@ Map::Tube::Kharkiv - Interface to the Kharkiv Metro Map.
 =head1 SYNOPSIS
 
  use Map::Tube::Kharkiv;
+
  my $obj = Map::Tube::Kharkiv->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
  my $line = $obj->get_line_by_id($line_id);
@@ -57,71 +55,101 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
 
 =head1 METHODS
 
-=over 8
+=head2 C<new>
 
-=item C<new()>
+ my $obj = Map::Tube::Kharkiv->new;
 
- Constructor.
+Constructor.
 
-=item C<get_all_routes($from, $to)> [EXPERIMENTAL]
+Returns instance of object.
 
- Get all routes from station to station.
- Returns reference to array with Map::Tube::Route objects.
+=head2 C<get_all_routes> [EXPERIMENTAL]
 
-=item C<get_line_by_id($line_id)>
+ my $routes_ar = $obj->get_all_routes($from, $to);
 
- Get line object defined by id.
- Returns Map::Tube::Line object.
+Get all routes from station to station.
 
-=item C<get_line_by_name($line_name)>
+Returns reference to array with Map::Tube::Route objects.
 
- Get line object defined by name.
- Returns Map::Tube::Line object.
+=head2 C<get_line_by_id>
 
-=item C<get_lines()>
+ my $line = $obj->get_line_by_id($line_id);
 
- Get lines in metro map.
- Returns reference to unsorted array with Map::Tube::Line objects.
+Get line object defined by id.
 
-=item C<get_node_by_id($station_id)>
+Returns Map::Tube::Line object.
 
- Get station node by id.
- Returns Map::Tube::Node object.
+=head2 C<get_line_by_name>
 
-=item C<get_node_by_name($station_name)>
+ my $line = $obj->get_line_by_name($line_name);
 
- Get station node by name.
- Returns Map::Tube::Node object.
+Get line object defined by name.
 
-=item C<get_shortest_route($from, $to)>
+Returns Map::Tube::Line object.
 
- Get shortest route between $from and $to node names. Node names in $from and $to are case insensitive.
- Returns Map::Tube::Route object.
+=head2 C<get_lines>
 
-=item C<get_stations($line)>
+ my $lines_ar = $obj->get_lines;
 
- Get list of stations for concrete metro line.
- Returns reference to array with Map::Tube::Node objects.
+Get lines in metro map.
 
-=item C<name()>
+Returns reference to unsorted array with Map::Tube::Line objects.
 
- Get metro name.
- Returns string with metro name.
+=head2 C<get_node_by_id>
 
-=item C<xml()>
+ my $station = $obj->get_node_by_id($station_id);
 
- Get XML specification of Kharkiv metro.
- Returns string with XML.
+Get station node by id.
 
-=back
+Returns Map::Tube::Node object.
+
+=head2 C<get_node_by_name>
+
+ my $station = $obj->get_node_by_name($station_name);
+
+Get station node by name.
+
+Returns Map::Tube::Node object.
+
+=head2 C<get_shortest_route>
+
+ my $route = $obj->get_shortest_route($from, $to);
+
+Get shortest route between $from and $to node names. Node names in $from and $to are case insensitive.
+
+Returns Map::Tube::Route object.
+
+=head2 C<get_stations>
+
+ my $stations_ar = $obj->get_stations($line);
+
+Get list of stations for concrete metro line.
+
+Returns reference to array with Map::Tube::Node objects.
+
+=head2 C<name>
+
+ my $metro_name = $obj->name;
+
+Get metro name.
+
+Returns string with metro name.
+
+=head2 C<xml>
+
+ my $xml_file = $obj->xml;
+
+Get XML specification of Kharkiv metro.
+
+Returns string with XML.
 
 =head1 EXAMPLE1
 
- # Pragmas.
+=for comment filename=print_kharkiv_route.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(decode_utf8 encode_utf8);
  use Map::Tube::Kharkiv;
 
@@ -139,12 +167,12 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
 
 =head1 EXAMPLE2
 
- # Pragmas.
+=for comment filename=print_kharkiv_def_xml_file.pl
+
  use strict;
  use utf8;
  use warnings;
 
- # Modules.
  use Map::Tube::Kharkiv;
 
  # Object.
@@ -161,11 +189,11 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
 
 =head1 EXAMPLE3
 
- # Pragmas.
+=for comment filename=print_kharkiv_image.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::GraphViz;
  use Map::Tube::GraphViz::Utils qw(node_color_without_label);
  use Map::Tube::Kharkiv;
@@ -191,19 +219,19 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
 
 =begin html
 
-<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Kharkiv/master/images/Kharkiv.png">
-  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Kharkiv/master/images/Kharkiv.png" alt="Харківський метрополітен" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Kharkiv/master/images/Kharkiv.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Kharkiv/master/images/Kharkiv.png" alt="Харківський метрополітен" width="300px" height="300px" />
 </a>
 
 =end html
 
 =head1 EXAMPLE4
 
- # Pragmas.
+=for comment filename=print_kharkiv_lines.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(encode_utf8);
  use Map::Tube::Kharkiv;
 
@@ -223,11 +251,11 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
 
 =head1 EXAMPLE5
 
- # Pragmas.
+=for comment filename=print_kharkiv_line_stations.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(decode_utf8 encode_utf8);
  use Map::Tube::Kharkiv;
 
@@ -290,7 +318,7 @@ Install the Map::Tube concrete metro modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Map-Tube-Kharkiv>
+L<https://github.com/michal-josef-spacek/Map-Tube-Kharkiv>
 
 =head1 AUTHOR
 
@@ -300,12 +328,14 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2017 Michal Josef Špaček
- Artistic License
- BSD 2-Clause License
+© 2014-2023 Michal Josef Špaček
+
+Artistic License
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
